﻿using System;
using System.Windows.Data;
using System.Collections.Generic;
using System.Data;
using System.Globalization;
namespace Helpers {

   [System.Windows.Markup.ContentProperty("Columns")]
   public class LookupConverter : IValueConverter {
      //usage in xaml: instantiate. add minimum 2 LookupConverterColumn, and fill them with items. first column is the key-Column, second the value-column, by default. if you add more columns, and want to convert a key to a value, specify the valueColumnIndex by ConverterParameter.

      public List<object> Keys {
         get { return Columns[0].Items; }
      }

      public List<LookupConverterColumn> _Columns = new List<LookupConverterColumn>();
      public List<LookupConverterColumn> Columns { get { return _Columns; } }

      private object Convert(object key, object valueColumnIndex, bool forward) {
         var column = 1;
         if(valueColumnIndex != null) int.TryParse(valueColumnIndex.ToString(), out column);
         if(column < 1 || column >= Columns.Count) {
            throw new Exception("valueColumnIndex should match an existing Column-Index > 0");
         }
         int[] cols = forward
            ? new int[] { 0, column }
            : new int[] { column, 0 };
         var indx = Columns[cols[0]].Items.IndexOf(key);
         return indx < 0 ? null : Columns[cols[1]].Items[indx];
      }

      /// <summary> retrieves a value associated with key. valueColumnIndex = 1 by default. </summary>
      public object Convert(object key, Type targetType, object valueColumnIndex, CultureInfo culture) {
         return Convert(key, valueColumnIndex, true);
      }

      /// <summary> retrieves the key associated with value. valueColumnIndex = 1 by default. </summary>
      public object ConvertBack(object value, Type targetType, object valueColumnIndex, CultureInfo culture) {
         return Convert(value, valueColumnIndex, false);
      }
   }

   [System.Windows.Markup.ContentProperty("Items")]
   public class LookupConverterColumn {
      public List<object> _Items = new List<object>();
      public List<object> Items { get { return _Items; } }
   }

}
